==> mi_0.02-01.tar.gz: mi/R/typecast.R <==
# ==============================================================================
#  function to select the variable type
# ==============================================================================
setMethod("typecast", signature( object = "ANY" ),     
  function ( object ) {
    if ( is.null ( object ) ) { 
      "NULL" 
    } else {
      values <- unique( object )[ !is.na( unique( object ) ) ]
      len    <- length ( values )
      if ( len == 1 )      { 
        # 1 category variable
        "fixed";
      } else if ( len == 2 ) { 
        # 2 category variable
        "dichotomous";
      } else {
        if ( is.numeric ( object ) == TRUE ) {
          # if the variable is numeric
          if ( len > 2 & len <= 5 ) { 
            # 3~5 category variable
            "ordered-categorical";
          } else if ( len > 5 & all ( values > 0 ) ) { 
            # more than 5 category and positive 
            "squareroot-continuous"; # "logscale-continuous" 
          } else if ( len > 5 & "0" %in% values & all ( values >= 0 ) ) {
            # more than 5 category with 0 and all positive numbers
            "mixed"; 
          } else {
            # everything else
            "continuous"; 
          }
        } else { 
          "unordered-categorical"; 
        }
      }
    }
  }
)

setMethod("typecast", signature( object = "matrix" ), 
  function ( object ) {    
    return( apply( object, 2, typecast ) )
  }
)
setMethod("typecast", signature( object = "data.frame" ), 
  function ( object ) {    
    return( apply( object, 2, typecast ) )
  }
)
setMethod("typecast", signature( object = "list" ), 
  function ( object ) {    
    return( lapply( object, typecast ) )
  }
)


is.less1.matrix <- function ( mat, check ) {
    return( sapply( mat, function(lst){ any( lst < 1, na.rm = TRUE ) }))
}
is.int.matrix <- function ( mat ) {
    return(apply( mat, 2, function(lst){ all( (lst - floor(lst))==0, na.rm = TRUE)}))
}
is.num.matrix <- function ( mat ) {
    return(sapply( mat, function(lst){ is.numeric(lst)}))
}
is.pos.matrix <- function ( mat ) {
    return(apply( mat, 2, function(lst){ all( lst >= 0, na.rm = TRUE)}))
}
is.complete.matrix <- function (mat) {
    return(sapply( mat, function(lst){ all(!is.na( lst ))}))
}
is.categorical <- function ( mat ) {
    return(apply( mat, 2, function(lst){ length ( names ( table ( lst ) ) ) <= 5 }))
}
recode.vector <- function ( vec ) {
    unique(vec)
}


# old name "datatype"
#
#setMethod("datatype", signature( object = "ANY" ),     
#  function ( object ) {
#    if ( is.null ( object ) ) { 
#      "NULL" 
#    } else {
#      values <- unique( object )[ !is.na( unique( object ) ) ]
#      len    <- length ( values )
#      if ( len == 1 )      { 
#        # 1 category variable
#        "fixed";
#      } else if ( len == 2 ) { 
#        # 2 category variable
#        "dichotomous";
#      } else {
#        if ( is.numeric ( object ) == TRUE ) {
#          # if the variable is numeric
#          if ( len > 2 & len <= 5 ) { 
#            # 3~5 category variable
#            "ordered-categorical";
#          } else if ( len > 5 & all ( values > 0 ) ) { 
#            # more than 5 category and positive 
#            "squareroot-continuous"; # "logscale-continuous" 
#          } else if ( len > 5 & "0" %in% values & all ( values >= 0 ) ) {
#            # more than 5 category with 0 and all positive numbers
#            "mixed"; 
#          } else {
#            # everything else
#            "continuous"; 
#          }
#        } else { 
#          "unordered-categorical"; 
#        }
#      }
#    }
#  }
#)
#
#setMethod("datatype", signature( object = "matrix" ), 
#  function ( object ) {    
#    return( apply( object, 2, datatype ) )
#  }
#)
#setMethod("datatype", signature( object = "data.frame" ), 
#  function ( object ) {    
#    return( apply( object, 2, datatype ) )
#  }
#)
#setMethod("datatype", signature( object = "list" ), 
#  function ( object ) {    
#    return( lapply( object, datatype ) )
#  }
#)

==> mi_0.02-03.tar.gz: mi/R/typecast.R <==
# ==============================================================================
#  function to select the variable type
# ==============================================================================
setMethod("typecast", signature( object = "ANY" ),     
  function (object){
  if (is.null(object)){ 
    "NULL" 
  } 
  else{
    values <- unique (object)[!is.na(unique(object))]
    len    <- length (values)
    if (len == 1){      # 1 category variable
      "fixed"
    } 
    else if (len == 2){ # 2 category variable
      "dichotomous"
    } 
    else {
      if (is.numeric(object)){       # if the variable is numeric
        if (len > 2 & len <= 5){   # 3~5 category variable
          "ordered-categorical"
        } 
        else if (len > 5 & all(values > 0)){ # more than 5 category and positive 
          "squareroot-continuous" 
            #"logscale-continuous" 
        } 
        else if (len > 5 & "0" %in% values & all(values >= 0)){# more than 5 category with 0 and all positive numbers
          "mixed" 
        } 
        else { # everything else
          "continuous" 
        }
      } 
      else { 
        "unordered-categorical" 
      }
    }
  }
}
)

setMethod("typecast", signature( object = "matrix" ), 
  function ( object ) {    
    return( apply( object, 2, typecast ) )
  }
)
setMethod("typecast", signature( object = "data.frame" ), 
  function ( object ) {    
    return( apply( object, 2, typecast ) )
  }
)
setMethod("typecast", signature( object = "list" ), 
  function ( object ) {    
    return( lapply( object, typecast ) )
  }
)


is.less1.matrix <- function ( mat, check ) {
    return( sapply( mat, function(lst){ any( lst < 1, na.rm = TRUE ) }))
}
is.int.matrix <- function ( mat ) {
    return(apply( mat, 2, function(lst){ all( (lst - floor(lst))==0, na.rm = TRUE)}))
}
is.num.matrix <- function ( mat ) {
    return(sapply( mat, function(lst){ is.numeric(lst)}))
}
is.pos.matrix <- function ( mat ) {
    return(apply( mat, 2, function(lst){ all( lst >= 0, na.rm = TRUE)}))
}
is.complete.matrix <- function (mat) {
    return(sapply( mat, function(lst){ all(!is.na( lst ))}))
}
is.categorical <- function ( mat ) {
    return(apply( mat, 2, function(lst){ length ( names ( table ( lst ) ) ) <= 5 }))
}
recode.vector <- function ( vec ) {
    unique(vec)
}


# old name "datatype"
#
#setMethod("datatype", signature( object = "ANY" ),     
#  function ( object ) {
#    if ( is.null ( object ) ) { 
#      "NULL" 
#    } else {
#      values <- unique( object )[ !is.na( unique( object ) ) ]
#      len    <- length ( values )
#      if ( len == 1 )      { 
#        # 1 category variable
#        "fixed"
#      } else if ( len == 2 ) { 
#        # 2 category variable
#        "dichotomous"
#      } else {
#        if ( is.numeric ( object ) == TRUE ) {
#          # if the variable is numeric
#          if ( len > 2 & len <= 5 ) { 
#            # 3~5 category variable
#            "ordered-categorical"
#          } else if ( len > 5 & all ( values > 0 ) ) { 
#            # more than 5 category and positive 
#            "squareroot-continuous" # "logscale-continuous" 
#          } else if ( len > 5 & "0" %in% values & all ( values >= 0 ) ) {
#            # more than 5 category with 0 and all positive numbers
#            "mixed" 
#          } else {
#            # everything else
#            "continuous" 
#          }
#        } else { 
#          "unordered-categorical" 
#        }
#      }
#    }
#  }
#)
#
#setMethod("datatype", signature( object = "matrix" ), 
#  function ( object ) {    
#    return( apply( object, 2, datatype ) )
#  }
#)
#setMethod("datatype", signature( object = "data.frame" ), 
#  function ( object ) {    
#    return( apply( object, 2, datatype ) )
#  }
#)
#setMethod("datatype", signature( object = "list" ), 
#  function ( object ) {    
#    return( lapply( object, datatype ) )
#  }
#)
